@@ -1,12 +1,12 @@
 use v6;
-use LWP::Simple;
+use HTTP::UserAgent;
 use NativeCall;
 
 class Build {
     method build($workdir) {
         # We only have a .dll file bundled on Windows; non-windows is assumed
         # to have a libarchive already.
-        return unless $*DISTRO.is-win;
+        return 1 unless $*DISTRO.is-win;
 
         my constant $file = "libarchive.dll";
         my constant $hash = "E6836E32802555593AEDAFE1CC00752CBDA0EBCE051500B1AA37847C30EFF161";
@@ -23,7 +23,14 @@ class Build {
         my $basedir = $workdir ~ '\resources';
 
         say "Fetching $file";
-        my $blob = LWP::Simple.get("http://www.p6c.org/~jnthn/libarchive/$file");
+        my $ua = HTTP::UserAgent.new;
+        my $response = $ua.get("http://www.p6c.org/~jnthn/libarchive/$file");
+        my $blob;
+        if $response.is-success {
+          $blob = $response.content;
+        } else {
+          die $response.status-line;
+        }
         say "Writing $file";
         spurt("$basedir\\$file", $blob);
 
